# -*- coding: utf-8 -*-

mapping = (
    "abgdezhiklmnxoprstyfwuABGDEZHIKLMNXOPRSTYFWU",
    "αβγδεζηικλμνξοπρστυφωθΑΒΓΔΕΖΗΙΚΛΜΝΞΟΠΡΣΤΥΦΩΘ",
)
reversed_specific_mapping = (
    "θΘ",
    "uU"
)
pre_processor_mapping = {
    "th": "θ",
    "ch": "χ",
    "ps": "ψ",
    "TH": "Θ",
    "CH": "Χ",
    "PS": "Ψ",
}



# -*- coding: utf-8 -*-

mapping = (
    u"abgdezhiklmnxoprstyfwuABGDEZHIKLMNXOPRSTYFWU",
    u"αβγδεζηικλμνξοπρστυφωθΑΒΓΔΕΖΗΙΚΛΜΝΞΟΠΡΣΤΥΦΩΘ",
)
reversed_specific_mapping = (
    u"θΘ",
    u"uU"
)
pre_processor_mapping = {
    u"th": u"θ",
    u"ch": u"χ",
    u"ps": u"ψ",
    u"TH": u"Θ",
    u"CH": u"Χ",
    u"PS": u"Ψ",
}
